# Better Site Automation
[![Telegram channel](https://img.shields.io/endpoint?url=https://runkit.io/damiankrawczyk/telegram-badge/branches/master?url=https://t.me/cum_insider)](https://t.me/cum_insider)
[![PyPI version info](https://img.shields.io/pypi/v/better-automation.svg)](https://pypi.python.org/pypi/better-automation)
[![PyPI supported Python versions](https://img.shields.io/pypi/pyversions/better-automation.svg)](https://pypi.python.org/pypi/better-automation)

```bash
pip install better-automation
```

Набор инструментов для автоматизации:
- Twitter (на запросах с библиотекой [tweepy-self](https://github.com/alenkimov/tweepy-self))
- Discord (на запросах с библиотекой [discord.py-self](https://github.com/dolfies/discord.py-self))
- Google (с Playwright и на запросах)

More libraries of the family:
- [tweepy-self](https://github.com/alenkimov/tweepy-self)
- [better-web3](https://github.com/alenkimov/better_web3)
- [better-proxy](https://github.com/alenkimov/better_proxy)
